<?php if (!defined('PmWiki')) exit();
/**
 * infobox.php
 * @author V.Krishn (vkrishn@insteps.net), Copyright 2005-2023
 * @note This file is part of Cookbook recipe "Infobox" for PmWiki;
 * You can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the  Free Software
 * Foundation; either version 2 of the License, or (at your option)
 * any later version. @see pmwiki.php for full details.
 *
 * @category pmwiki/cookbook
 * @package infobox
 * @copyright Copyright (c) 2005-2023 V.Krishn (vkrishn@insteps.net)
 * @license GPL
 * @version 2.4.1
 */

global $Infobox;
if ( ! IsEnabled($EnableInfobox, 0)) return;

## Current script variables
    if ( ! defined('DS') ) { define('DS', DIRECTORY_SEPARATOR); }
    $Infobox['Current']['dir'] = dirname(__FILE__);
    $EnableInfoboxDebug = 0; # 0=no debug, 1=debug messages, 2=all
    $Infobox['debug']['msg'] = array();

## Get cookbook/modules meta and version variables
## @todo xml version of the metapage
    if (file_exists($Infobox['Current']['dir'] . DS . "version.php")) {
      include_once($Infobox['Current']['dir'] . DS . "version.php");
}

## Get wiki group and pagename for use
    $Infobox['page']['CurrentGroup'] = FmtPageName('$Group', $pagename);
    $Infobox['page']['CurrentName'] = FmtPageName('$Name', $pagename);

## Set default values for GROUP and default layermenu MENU script(wiki page)
    SDV($Infobox['default']['MenuGroupReserved'], 'Infobox'); #not implemented
    SDV($Infobox['default']['MenuPageGroup'], 'Content');
    SDV($Infobox['default']['MenuPageName'], 'Infotips');

// ========================================================
 /*
   NOTE: CAUTION
   Use of this recipe lets you insert arbitrary JavaScript Code.
   DO NOT disable the security code in "infobox.php".
   Make appropriate settings with the default password = infoboxpass
     in infobox.php or in config.php if commenting below.
   Read main documentation on page protection and passwords.
   Simple security precaution below.
  */
  global $DefaultPasswords;
  $tmpLen = strlen($Infobox['default']['MenuPageName']);
  if ($Infobox['default']['MenuPageName'] === substr($pagename, -$tmpLen)) {
    $DefaultPasswords['edit'] = crypt('infoboxpass');
    $DefaultPasswords['attr'] = crypt('infoboxpass');
  }
// ========================================================

## Set modules/cookbook install variables.
## Change these values accordingly.
    SDV($Infobox['Install']['location'], '0'); # 0=field, 1=farm, 2=others
    SDV($Infobox['Install']['path'], 'cookbook'); # relative to field or farm
    SDV($Infobox['Install']['dir'], 'infobox'); # folder where installed
    SDV($Infobox['Install']['icon']['dir'], 'icons'); # icons to be used in menus


    // --------------------------------------
    // Would not require to edit below this
    // --------------------------------------



// //////////////////////////////////////////////////////////
//(:infobox infotipName|displayText :)
//    infotipName - infotip name set in js textfile
//    displayText - text to be displayed
// //////////////////////////////////////////////////////////

/* Markups defined below work like a charm...
   Just see if it does not clash with any other markups.
   Enable only the ones you want to make use of.
 */
if(function_exists('Markup_e')) {
  # new format, no /e , IMPORTANT: pmwiki-2.2.58+ and php 5.5x
  Markup('infobox','>inline','/\\(:infobox(.*?):\\)/','CallbackInfoBoxFmt');
  Markup("~~","<inline",'/~~(.+?)~~/','CallbackInfoBoxFmt');
  Markup("**","<block",'/\\*{2}(.+?)\\*{2}/','CallbackInfoBoxFmt');
} else {
  /* old format, for pmwiki < 2.2.58
     if using php 5.5x see pmwiki documentation as how to suppress
       deprecated preg_replace errors. */
  Markup('infobox','>inline','/\\(:infobox(.*?):\\)/e',"InfoBoxFmt('$1')");
  Markup("~~","<inline",'/~~(.+?)~~/e',"InfoBoxFmt('$1')");
  Markup("**","<block",'/\\*{2}(.+?)\\*{2}/e',"InfoBoxFmt('$1')");
}

function CallbackInfoBoxFmt($m) { return InfoBoxFmt($m[1]); }

function InfoBoxFmt($params) {
  global $Infobox,
         $HTMLHeaderFmt, $HTMLFooterFmt, $HTMLStylesFmt,
         $EnableInfoboxDebug;
  static $infoboxDrawCount; static $_fs;
  $infoboxDrawCount++;
  include_once('scripts/functions.php');
  include_once('scripts/set_path_file.php');
  infobox_init_lib();

  $args = ParseArgs($params);
  $count = isset($args['']) ? count($args[""]) : 0; // issue as of PHP 7.2
  if($EnableInfoboxDebug > 0) {
    $Infobox['debug']['msg']['args'][] = $args;
  }
  $infoboxtext = isset($args['']) ? implode(' ',$args['']) : '';

  if(isset($args['id'])) {
    $id = $args['id'];
    $_fs = $_fs . 'ib.infobox("'.$id.'"); ';
    $HTMLFooterFmt['infoboxfs'] = 
        '<script type="text/javascript">'.$_fs.'</script>';
    $HTMLStylesFmt['id-'.$id] = ' #' . $id . ' .lnktip { margin:0px; }'; # TODO
  }

  $InfoBoxHtmlFmt = ''; $OnMouseFmt = ''; $HereClsNm = 'infoboxhere';
  if(strlen(trim($infoboxtext)) > 0) {
    include_once('scripts/set_tips_file.php');

    $IBName = trim(substr($infoboxtext,0,strpos($infoboxtext,"|")));
    $InfoBoxName = keep($IBName);
    $IBLinkText = substr(strstr($infoboxtext,"|"),1);

    if('none' !== $IBName && $IBName !== '') {
      preg_match("/^#/", $IBName, $m);
      if(@$m[0]) {
        $OnMouseFmt = 'onmouseover="ib.cotip(this)"'; $HereClsNm = 'cotip';
      } else {
        $OnMouseFmt = 'onmouseover="ib.tip(\'' . $InfoBoxName . '\')"' . ' onmouseout="ib.untip()"';
        $HereClsNm = 'infoboxhere';
      }
    }
    $InfoBoxHtmlFmt = "<span class='$HereClsNm' $OnMouseFmt>$IBLinkText</span>";

    if($EnableInfoboxDebug > 0) {
      //$Infobox['debug']['msg']['IBPageFmt'][] = $IBPageFmt;
    }
  }

  ## Debug
  $infoboxDebugMsg = @InfoboxDebug($EnableInfoboxDebug);
  if($infoboxDebugMsg) {
    @$HTMLFooterFmt['infobox_DEBUG'] =
        '<pre>' . $infoboxDebugMsg . '</pre>' . "\n";
  }


  return $InfoBoxHtmlFmt;

}



